@@ -81,7 +81,7 @@ def get_reqs_from_files(requirements_files):
     return []
 
 
-def parse_requirements(requirements_files=None):
+def parse_requirements(requirements_files=None, strip_markers=False):
 
     if requirements_files is None:
         requirements_files = get_requirements_files()
@@ -104,7 +104,8 @@ def parse_requirements(requirements_files=None):
         # -r other-requirements.txt
         if line.startswith('-r'):
             req_file = line.partition(' ')[2]
-            requirements += parse_requirements([req_file])
+            requirements += parse_requirements(
+                [req_file], strip_markers=strip_markers)
             continue
 
         try:
@@ -130,6 +131,11 @@ def parse_requirements(requirements_files=None):
             reason = 'Index Location'
 
         if line is not None:
+            if strip_markers:
+                semi_pos = line.find(';')
+                if semi_pos < 0:
+                    semi_pos = None
+                line = line[:semi_pos]
             requirements.append(line)
         else:
             log.info(
